Name:      ovs-agent
Version:   2.3
Release: 38
Summary:   Agent for Oracle VM
License:   GPL
Group:     System Environment/Daemons
URL:       http://www.oracle.com/virtualization
Source:    %{name}-%{version}.tar.bz2
Patch1: dummy.patch
Patch2: patch82.patch_8347
Patch3: patch7308.patch_25427
Patch4: patch1558.patch_2340
Patch5: patch9050.patch_13974
# End Oracle Patches
BuildArch: noarch
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root
Requires:  python >= 2.4
Requires:  compat-python-virtinst
Requires:  python-simplejson >= 2.0.7
Requires:  multiprocessing >= 2.6.1.1
Requires:  open-ovf >= 0.1

%description
Agent daemon for Oracle VM.


%prep
%setup -q
%patch1 -p0
%patch2 -p0
%patch3 -p0
%patch4 -p0
%patch5 -p0


%build
make build


%install
rm -rf $RPM_BUILD_ROOT
make DESTDIR=${RPM_BUILD_ROOT} install
mkdir -p ${RPM_BUILD_ROOT}/etc/init.d
install --mode=755 ovs-agent.init ${RPM_BUILD_ROOT}/etc/init.d/ovs-agent


%clean
rm -rf $RPM_BUILD_ROOT


%pre
# only when it is an upgrade
if [ "$1" = 2 -a -d /opt/ovs-agent-2.3 ]; then
    python << EOF
import sys
sys.path.append("/opt/ovs-agent-2.3")

from xmlrpclib import ServerProxy
from OVSCDS import db_load
from OVSCommons import parse_result

ha_enable = db_load("cluster", "pool_ha_enable", get=True)
if not ha_enable:
    sys.exit(0)

master_vip = db_load("cluster", "master_vip", get=True)
if master_vip:
    print "Please disable master failover before upgrade."
    sys.exit(1)

my_hostname = db_load("LOCAL_DB,node", "registered_hostname")
master_hostname = db_load("cluster", "master_hostname")

# it is the master server
if my_hostname == master_hostname:
    sys.exit(0)

master_srv = db_load("srv", master_hostname)
master_agt_url = master_srv["agt_url"]
sp = ServerProxy(master_agt_url)

try:
    result = sp.get_agent_version()
except Exception, e:
    print "Cannot get ovs-agent version from %s: %s" % (master_hostname, e)
    sys.exit(2)

if not result.startswith("success"):
    print "Cannot get ovs-agent version from %s: %s" % (master_hostname, result)
    sys.exit(2)

# 2.3-19 => [2, 3, 19]
agt_ver = parse_result(result)["agent_version"]
parts = agt_ver.split("-")
ver = parts[0].split(".")

t = []
# version
t.append(int(ver[0]))
t.append(int(ver[1]))
#release
t.append(int(parts[1]))

if t < [2, 3, 38]:
    print "Please upgrade the master server first."
    sys.exit(3)

EOF
fi

%post
# http://www.ibm.com/developerworks/linux/library/l-rpm3.html
if [ "$1" = 1 ]; then
    /sbin/chkconfig --add ovs-agent
fi

# configure agent with default value, mainly for
# 1) regenerating admin password
# 2) if upgrade, update the default config file
/etc/init.d/ovs-agent configure >/dev/null <<EOF





EOF

# autogenerate a key for the agent for SSL configuration
# use the hostname as extra data
if [ ! -f "/etc/ovs-agent/cert/key.pem" -o ! -f "/etc/ovs-agent/cert/certificate.pem" ]; then
    _hostname=$(uname -n)
    cd /etc/ovs-agent/cert
    openssl genrsa -out key.pem 1024
    openssl req -new -key key.pem -out request.pem << EOF
.
.
.
.
.
${_hostname}
.
.
.
EOF
    openssl x509 -req -days 1000 -in request.pem -signkey key.pem -out certificate.pem
fi

restart_xend=0

# set dlm lock
if ! LC_ALL=C grep -q "^(xend-domains-lock-path \+/opt/ovs-agent-2.3/utils/dlm.py)" /etc/xen/xend-config.sxp 2>/dev/null ; then
    LC_ALL=C grep -v "xend-domains-lock-path" /etc/xen/xend-config.sxp >/tmp/xend-config.sxp 2>/dev/null
    echo "(xend-domains-lock-path /opt/ovs-agent-2.3/utils/dlm.py)" >>/tmp/xend-config.sxp
    /bin/mv /tmp/xend-config.sxp /etc/xen/xend-config.sxp
    restart_xend=1
fi

# set domain shutdown hook
if ! LC_ALL=C grep -q "^(domain-shutdown-hook \+/opt/ovs-agent-2.3/utils/hook_vm_shutdown.py)" /etc/xen/xend-config.sxp 2>/dev/null ; then
    LC_ALL=C grep -v "domain-shutdown-hook" /etc/xen/xend-config.sxp >/tmp/xend-config.sxp 2>/dev/null
    echo "(domain-shutdown-hook /opt/ovs-agent-2.3/utils/hook_vm_shutdown.py)" >>/tmp/xend-config.sxp
    /bin/mv /tmp/xend-config.sxp /etc/xen/xend-config.sxp
    restart_xend=1
fi

if [ "$restart_xend" = "1" ]; then
    if xend status >/dev/null 2>&1 ; then
        vms=`xm list 2>/dev/null |wc -l`
        if [ "$vms" = "2" ]; then
            service xend restart >/dev/null 2>&1
        else
            echo "Please restart xend manually."
        fi
    fi
fi

%preun
# execute this only if we are NOT doing an upgrade
if [ "$1" = 0 ]; then
    /sbin/service ovs-agent stop --force --disable-nowayout >/dev/null 2>&1
    /sbin/chkconfig --del ovs-agent

    # remove the symbol links
    if [ -L "/opt/ovs-agent-latest" ]; then
        rm -f "/opt/ovs-agent-latest"
    fi
    if [ -L "/opt/ovs-agent-2.2" ]; then
        rm -f "/opt/ovs-agent-2.2"
    fi

    restart_xend=0

    # remove dlm lock
    if LC_ALL=C grep -q "^(xend-domains-lock-path \+/opt/ovs-agent-2.3/utils/dlm.py)" /etc/xen/xend-config.sxp 2>/dev/null ; then
        LC_ALL=C grep -v "xend-domains-lock-path" /etc/xen/xend-config.sxp >/tmp/xend-config.sxp 2>/dev/null
        /bin/mv /tmp/xend-config.sxp /etc/xen/xend-config.sxp
        restart_xend=1
    fi

    # remove domain shutdown hook
    if LC_ALL=C grep -q "^(domain-shutdown-hook \+/opt/ovs-agent-2.3/utils/hook_vm_shutdown.py)" /etc/xen/xend-config.sxp 2>/dev/null ; then
        LC_ALL=C grep -v "domain-shutdown-hook" /etc/xen/xend-config.sxp >/tmp/xend-config.sxp 2>/dev/null
        /bin/mv /tmp/xend-config.sxp /etc/xen/xend-config.sxp
        restart_xend=1
    fi

    if [ "$restart_xend" = "1" ]; then
        if xend status >/dev/null 2>&1 ; then
            vms=`xm list 2>/dev/null |wc -l`
            if [ "$vms" = "2" ]; then
                service xend restart >/dev/null 2>&1
            else
                echo "Please restart xend manually."
            fi
        fi
    fi
fi


%files
%defattr(-,root,root)
/etc/init.d/ovs-agent
/opt/%{name}-%{version}
%attr(755,root,root) /opt/%{name}-%{version}/utils/upgrade.py


%changelog
* Tue Apr 13 2010 Junjie Wei <junjie.wei@oracle.com> - 2.3-38
- Ignore precheck for 2.1.5 (keshav.sharma@oracle.com)
- correct a typo in utils/cleanup.py
- update cluster.db after SR initialization for 2.2.1 upgrade
- perform upgrade precheck in the %pre section of ovs-agent.spec
- bugfix #9299260, limit SR changes to the master server only
- fix TypeError in ha_check_cpu_compatibility()
- fix 2.2.0 to 2.2.1 upgrade issue, save master_agt_url in cluster.db

* Thu Mar 18 2010 Keshav Sharma <keshav.sharma@oracle.com> - 2.3-37 
- Fixed typo in for multipath device. 

* Tue Mar 9 2010 Junjie Wei <junjie.wei@oracle.com> - 2.3-36
- bugfix #9303165, collect_srv_stat() blocks till collection is done
- bugfix #9444263, fix system time issue

* Sat Mar 6 2010 Junjie Wei <junjie.wei@oracle.com> - 2.3-35
- fix NameError in get_servers_perf()

* Wed Mar 3 2010 Junjie Wei <junjie.wei@oracle.com> - 2.3-34
- fix "command not found" errors, 'blkid' to '/sbin/blkid' and 'runlevel' to '/sbin/runlevel'
- raise exception if there is no server in cluster_setup() and cluster_check_prerequisite()
- fix UnboundLocalError in cluster_setup()
- Bugfix #9440241, UnboundLocalError in cluster_precheck()
- fix the %preun issue in ovs-agent.spec

* Tue Mar 2 2010 Junjie Wei <junjie.wei@oracle.com> - 2.3-34
- bugfix #9329918, hook VM shutdown to update manual_shutdown flag
- new script for VM shutdown hook: utils/hook_vm_shutdown.py
- new API: update_manual_shutdown()
- new API: ha_hook_vm_shutdown()
- bugfix in ha_hook_shutdown_mode(), raise Exception
- bugfix in db_get_vm_path(), return an empty string when query fails
- enhancement of db/db_kv.py, accept bool values

* Mon Mar 1 2010 Junjie Wei <junjie.wei@oracle.com> - 2.3-34
- fix V2V process sync issue

* Thu Feb 25 2010 Junjie Wei <junjie.wei@oracle.com> - 2.3-33
- make cluster prerequisite check compatible with previous releases

* Wed Feb 24 2010 Junjie Wei <junjie.wei@oracle.com> - 2.3-33
- bugfix #9382488, enhance collect_srv_stat() with multiprocessing
- set default cache timeout of collect_srv_stat() to 5s

* Tue Feb 23 2010 Junjie Wei <junjie.wei@oracle.com> - 2.3-33
- enhancement of error message logging, keep all stack trace entries
- enhancement of timeout_command(), set default timeout to 10s
- bugfix #9354044, kill rpmq process with SIGTERM instead of SIGKILL
- set default fork_max to 32 in OVSMultiprocess
- enhancement of get_servers_perf(), exclude unreachable servers
- bugfix #9303890, enhance get_live_vms() with multiprocessing

* Thu Feb 11 2010 Junjie Wei <junjie.wei@oracle.com> - 2.3-32
- new API for cluster_precheck(): ha_check_ovs_base()
- new API for cluster_precheck(): ha_check_storage_repos()
- new API for cluster_precheck(): ha_get_ocfs2_config()
- new API for cluster_precheck(): ha_check_ocfs2_config()
- bugfix #9299213 and #9299307, check prerequisites before cluster setup
- alias ha_check_cluster_prerequisite() to cluster_precheck()
- bugfix of usage() in utils/dlm.py
- enhancement of clusterm_stop_heartbeat(), better exception handling
- cleanup script, utils/cleanup.py

* Wed Feb 10 2010 Junjie Wei <junjie.wei@oracle.com> - 2.3-32
- bugfix#9236703, write permission testing on SR initialization
- enhancement of utils/repos.py, better exception handling on SR initialization
- bugfix of SR listing in utils/repos.py
- bugfix of JSON exception parser in OVSProtocol
- new API for cluster_precheck(): ha_check_cpu_compatibility()
- new API for cluster_precheck(): ha_get_hostname_ip()
- new API for cluster_precheck(): ha_check_hostname_ip()

* Tue Feb 9 2010 Junjie Wei <junjie.wei@oracle.com> - 2.3-32
- bugfix #9350986, increase default timeout of CDS

* Mon Feb 8 2010 Junjie Wei <junjie.wei@oracle.com> - 2.3-32
- rewrite _dispatch() in OVSServices for better performance
- enhancement of node teardown, offline o2cb & remove cluster.conf

* Thu Feb 4 2010 Junjie Wei <junjie.wei@oracle.com> - 2.3-32
- bugfix of VM type detection

* Fri Jan 29 2010 Keshav Sharma <keshav.sharma@oracle.com> - 2.3-31
- fix 2.1 to 2.2 upgrade issue

* Fri Jan 29 2010 Junjie Wei <junjie.wei@oracle.com> - 2.3-31
- bugfix #9300579, reserve 100 MB for cluster configurations in each SR

* Wed Jan 27 2010 Junjie Wei <junjie.wei@oracle.com> - 2.3-30
- set cluster_setup() lock timeout to 600 seconds
- handle exceptions in cluster_setup()

* Tue Jan 26 2010 Tiger Zhang <tiger.zhang@oracle.com> - 2.3-30
- bugfix #9294066, handle exceptions in unregister_server()
- add wait() in OVSV2V.py

* Tue Jan 26 2010 Junjie Wei <junjie.wei@oracle.com> - 2.3-30
- bugfix of get_servers_perf(), change the separator to ";"
- bugfix #9293318, serialize cluster_setup()

* Sun Jan 24 2010 Junjie Wei <junjei.wei@oracle.com> - 2.3-30
- serialize the process of server selection and free memory update in start_vm()
- unit testing of starting multiple guests

* Sat Jan 23 2010 Junjie Wei <junjie.wei@oracle.com> - 2.3-30
- enhance collect_srv_stat() with cache and exclusive locks

* Fri Jan 22 2010 Junjie Wei <junjie.wei@oracle.com> - 2.3-30
- enhancement of CDS, timeout and interval support

* Thu Jan 21 2010 Junjie Wei <junjie.wei@oracle.com> - 2.3-30
- bugfix of servers_do()
- enhance get_servers_perf() with multiprocessing

* Tue Jan 20 2010 Junjie Wei <junjie.wei@oracle.com> - 2.3-30
- stop cluster heartbeat before umounting root sr

* Wed Jan 20 2010 Hongxi Ma <hongxi.ma@oracle.com> - 2.3-29
- bugfix #9238623, list_dir returns only non-empty dirs

* Sat Jan 16 2010 Junjie Wei <junjie.wei@oracle.com> - 2.3-29
- bugfix #9245740, ocfs2 configuration corruption

* Tue Jan 12 2010 Junjie Wei <junjie.wei@oracle.com> - 2.3-28
- bugfix #9191319 and #9141304, timeout support for xm and rpm queries

* Fri Dec 25 2009 Junjie Wei <junjie.wei@oracle.com> - 2.3-27
- bugfix of symbol link creation

* Fri Dec 25 2009 Hongxi Ma <hongxi.ma@oracle.com> - 2.3-27
- bugfix #9180000, DB_RUNRECOVERY Error

* Wed Dec 23 2009 Junjie Wei <junjie.wei@oracle.com> - 2.3-26
- better logging for cluster_precheck()

* Thu Dec 17 2009 Junjie Wei <junjie.wei@oracle.com> - 2.3-26
- bugfix #9949, check if i am the master node
- save master_agt_url when registering the master node
- check server status only when HA is enabled
- keep DLM_LOCK_MASTER when removing dlm locks

* Wed Dec 16 2009 Junjie Wei <junjie.wei@oracle.com> - 2.3-25
- bugfix #9191053, get the node list from ovs-agent db instead of cluster.conf
- bugfix #9878, sync dlm locks when doing cluster setup/teardown

* Fri Dec 11 2009 Hongxi Ma <hongxi.ma@oracle.com> - 2.3-24
- bugfix #9112469, detailed error message when "Cluster root not found."

* Fri Dec 4 2009 Hongxi Ma <hongxi.ma@oracle.com> - 2.3-24
- bugfix #9151725, REQUIRE SYMLINKS /OPT/OVS-AGENT-LATEST AND /OPT/OVS-AGENT-2.2

* Thu Nov 26 2009 Junjie Wei <junjie.wei@oracle.com> - 2.3-23
- enhancement of sparse file copy between different servers
- enhancement of sparse file copy on the same server
- enhancement of virtual disk creation with sparse files

* Mon Nov 9 2009 Junjie Wei <junjie.wei@oracle.com> - 2.3-22
- change the message in utils/repos.py
- add log for server selection

* Fri Nov 6 2009 Junjie Wei <junjie.wei@oracle.com> - 2.3-22
- enhancement of utils/repos.py, better support of cluster init
- rewrite clusterm_teardown(), keep every backup of the mount directory

* Thu Nov 5 2009 Junjie Wei <junjie.wei@oracle.com> - 2.3-21
- enhancement of utils/repos.py: better error messages
- enhancement of unregister_server(): keep sr settings on the master node
- bugfix of cluster_prepare_ocfs2_conf(): sync ocfs2 conf file to every node in the cluster
- update do_rpc.py: support True and False
- enhancement of db/db_*.py: support db names with .db extension
- enhancement of db/db_del.py: remove unnecessary questions

* Wed Nov 4 2009 Hongxi Ma <hongxi.ma@oracle.com> - 2.3-21
- bugfix #9078535, update agent_version in "register_server"

* Tue Nov 3 2009 Junjie Wei <junjie.wei@oracle.com> - 2.3-21
- make ovs-agent compatible with previous ovs-manager release

* Tue Nov 3 2009 Hongxi Ma <hongxi.ma@oracle.com> - 2.3-20
- bugfix #9078535, KeyError: 'agent_version'
- bugfix #9078621, 'agent_version' after update_agent_password called

* Mon Oct 26 2009 Junjie Wei <junjie.wei> - 2.3-20
- bugfix of switch arp table refresh

* Thu Oct 22 2009 Junjie Wei <junjie.wei> - 2.3-20
- bugfix of VIP configuration, deal with alias device names
- cleanup cluster vip before vip registration
- bugfix of cluster setup, validate heartbeat file before starting heartbeat
- when ovs-agent fails to start heartbeat, stop & start heartbeat to remove & setup
  the dmnfs device according to the currect heartbeat file

* Mon Oct 12 2009 Junjie Wei <junjie.wei@oracle.com> - 2.3-19
- save registered_ip to local db when upgrade finishes
- update master_weight in upgrade process

* Sat Oct 10 2009 Junjie Wei <junjie.wei@oracle.com> - 2.3-18
- bugfix #8974425, enhancement of storage management
- bugfix #9008033, rewrite get_master_ip()
- bugfix #9008382, remove shutdown flag when upgrade finishes
- bugfix #9008413, remove invalid links on sr initialization

* Fri Oct 9 2009 Keshav Sharma <keshav.sharma@oracle.com> - 2.3-17
- updated repos.py to allow deletion of root sr without warning if no server registered

* Fri Oct 9 2009 Tiger Zhang <tiger.zhang@oracle.com> - 2.3-16
- kill_process_tree refactory

* Fri Oct 9 2009 Junjie Wei <junjie.wei@oracle.com> - 2.3-16
- when deleting an SR, umount it on all servers in the cluster
- bugfix #8997528, do not config ocfs2 when there is no server
- bugfix #8978256, enhancement of SR listing/deleting
- new APIs: sr_delete() and sr_umount()

* Fri Oct 9 2009 Hongxi Ma <hongxi.ma@oracle.com> - 2.3-16
- new is_partition_of,fix:mpath10 not listed due to existence of mpath1

* Wed Sep 30 2009 Junjie Wei <junjie.wei@oracle.com> - 2.3-16
- provide better error message when getting device UUID fails
- backup config files before upgrade
- more debug messages for upgrade

* Wed Sep 30 2009 Junjie Wei <junjei.wei@oracle.com> - 2.3-15
- save master_hostname and master_agt_url when doing upgrade
- save init_root flag to keep sr settings during cluster_teardown()

* Tue Sep 29 2009 Junjie Wei <junjie.wei@oracle.com> - 2.3-15
- sleep after mount and umount to ensure that the storage is ready
- new autostart job categories: command (sync) and command_bg (async)
- run mode of ovs-agent upgrade switched from command_bg to command
- bugfix #8969385, #8966218, #8969440, process synchronization control
- bugfix #8969114, cciss disk support and get_dev_spec() enhancement
- bugfix #8970135, enhancement of shared disk search
- try to leave shutdown mode when ovs-agent starts
- bugfix #8970164, raise ERR_NO_SERVER_SELECTED

* Tue Sep 29 2009 Hongxi Ma <hongxi.ma@oracle.com> - 2.3-15
- set dom0's weight to 512 when agent starts

* Mon Sep 28 2009 Junjie Wei <junjie.wei@oracle.com> - 2.3-15
- bugfix #8966463 and #8967198, bound VIP to the master node
- bugfix of VIP cleanup
- bugfix #8967173, save cluster_root_sr_uuid on initialization
- bugfix #8967172, bugfix of server role change
- bugfix #8967227, bugfix of cluster_teardown()
- bugfix of check_server_status(), UnboundLocalError

* Sun Sep 27 2009 Junjie Wei <junjie.wei@oracle.com> - 2.3-15
- bugfix #8904717, ocfs2 local feature detection
- bugfix #8903539, teardown a single node

* Fri Sep 25 2009 Junjie Wei <junjie.wei@oracle.com> - 2.3-14
- bugfix of ocfs2 cluster configuration
- enhancement of cluster_teardown() and cluster_cleanup_vip()

* Thu Sep 24 2009 Tiger Zhang <tiger.zhang@oracle.com> - 2.3-13
- bugfix #8904030, handle cds lock timeout exception
- remove free memory checking in unpause_vm

* Thu Sep 24 2009 Junjie Wei <junjie.wei@oracle.com> - 2.3-13
- bugfix in cluster_setup()
- bugfix #8941079
- bugfix #8786030, sleep after storage initialization
- disable HA support for single node cluster

* Wed Sep 23 2009 Junjie Wei <junjie.wei@oracle.com> - 2.3-13
- bugfix #8919753, global variable error in utils/repos.py
- cluster_teardown(): new option added, keep_cluster_root
- util/repos.py: teardown with keep_cluster_root=False when deleting root sr
- util/repos.py: print the mount point when operation fails
- new exposed api: cluster_precheck()
- check cluster setup prerequisite before setup

* Wed Sep 23 2009 Hongxi Ma <hongxi.ma@oracle.com> - 2.3-13
- bugfix #8903539, update the hint when deleting root sr
- bugfix #8795326, remove "vfb" section before setting vnc config for HVM

* Tue Sep 22 2009 Tiger Zhang <tiger.zhang@oracle.com> - 2.3-13
- Add check_cluster_prerequisite for bug #8903524

* Tue Sep 22 2009 Junjie Wei <junjie.wei@oracle.com> - 2.3-13
- test the connection to ovs-agent before sr operations
- umount the storage after it is deleted
- umount with -fl options
- bugfix #8910697, agent upgrade issue in a cluster env
- deal with comments and blank lines when parsing /etc/fstab
- rewrite clusterm_init_sr() to support upgrade better
- log support for ovs-agent upgrade

* Mon Sep 21 2009 Junjie Wei <junjie.wei@oracle.com> - 2.3-13
- remove dedicated_server from installation log since it is not used
- bugfix #8914823, check device uuid when initializing the storage
- bugfix #8910826, ha support for local disks, start vm
- bugfix #8904717, ha support for local disks, enable vip
- bugfix #8903524, deleting root sr will cause configuration lost
- bugfix #8882727, remove invalid /OVS link
- bugfix #8870178, clear vip when HA is diabled or cluster is deleted
- bugfix #8746618, document the cluster setup prerequisite

* Mon Sep 21 2009 Hongxi Ma <hongxi.ma@oracle.com> - 2.3-13
- bugfix #8928193, KeyError "vcaps"
- repos.py -d: Add hint when deleting the current root SR

* Fri Sep 18 2009 Junjie Wei <junjie.wei@oracle.com> -2.3-13
- enhancement of device detection: support of hp servers
- make ha available for all storage types
- check storage consistency with UUID
- remove invalid link after cluster_teardown()
- get storage spec when listing sr on different nodes
- keep storage settings when doing cluster_teardown()

* Fri Sep 18 2009 Hongxi Ma <hongxi.ma@oracle.com> - 2.3-13
- bugfix #8815185, new api: validate_master_vip(vip, base_ip)

* Thu Sep 17 2009 Junjie Wei <junjie.wei@oracle.com> - 2.3-12
- bugfix #8903539, teardown cluster when root sr is deleted
- bugfix #8786030, do not select node with local conf when setting vip
- new API: get_server_list_with_local_conf() and get_agent_conf_mode()
- backup instead of delete when doing cluster_teardown()

* Tue Sep 15 2009 Junjie Wei <junjie.wei@oracle.com> - 2.3-12
- new functions: cluster_teardown() and cluster_cleanup_vip()
- enhancement of network interface detection
- enhancement of storage management, tear down the cluster when
  the root sr is deleted
- cleanup vip when cluster ha is disabled
- new script: utils/rsh.py
- rewrite check_sys_passwd() with no temporary file
- teardown the node when unregister_server()

* Tue Sep 15 2009 Tiger Zhang <tiger.zhang@oracle.com> - 2.3-12
- Add reset_vm_stat

* Mon Sep 14 2009 Junjie Wei <junjie.wei@oracle.com> -2.3-12
- umount the storage when sr creation fails
- delete temporaray directory after sr creation

* Fri Sep 11 2009 Junjie Wei <junjie.wei@oracle.com> - 2.3-11
- bugfix in _check_free_mem()
- make default dirs when init sr

* Thu Sep 10 2009 Junjie Wei <junjie.wei@oracle.com> - 2.3-11
- various bugfix

* Thu Sep 10 2009 Tiger Zhang <tiger.zhang@oracle.com> - 2.3-11
- handle exceptions in get_storage_repositories()

* Wed Sep 9 2009 Junjie Wei <junjie.wei@oracle.com> - 2.3-11
- cluster HA works on nfs and clustered ocfs2
- simplify the usage of utils/repos.py
- get device name from uuid, supports ext3 and ocfs2

* Wed Sep 9 2009 Tiger Zhang <tiger.zhang@oracle.com> - 2.3-11
- Add get_storage_repositories, get_vcpus_max

* Fri Sep 4 2009 Junjie Wei <junjie.wei@oracle.com> - 2.3-11
- bugfix #8790371, start o2cb service when ovs-agent starts
- enhancement of ocfs2 cluster conf generation
- new api: cluster_prepare_ocfs2_conf()
- reset local_db flag after cluster root initialization
- bugfix in xen_correct_qos_cfg()
- bugfix in utl_wget(), get realpath of the given path
- enhancement of utl_get_storage_repos(): raise exception when no sr is found

* Thu Sep 3 2009 Junjie Wei <junjie.wei@oracle.com> - 2.3-11
- bugfix #8859588, disable 1) master failover and 2) virtual ip when ovs-agent
  starts in a signle node cluster with a local ocfs2 disk as the cluster root.

* Wed Sep 2 2009 Tiger Zhang <tiger.zhang@oracle.com> - 2.3-10
- Fix Bug 8833471. Delete .wget directory when wget failed.
- Add XMON module for serializing Agent API return.
- return key value pairs string from get_domains_stat instead of JSON.

* Wed Sep 2 2009 Hongxi Ma <hongxi.ma@oracle.com> - 2.3-10
- to also remove atask data under CONFIG_DIR_CLUSTER in init_asyncenv()
- to remove potential bug when PID rotates back from MAX_PID

* Wed Sep 2 2009 Junjie Wei <junjie.wei@oracle.com> - 2.3-10
- bugfix in get_server_list_with_conn_err()
- enhancement of utils/agent_upgrade.py
- bugfix in OVSAgentAutoStart.py
- expose cluster_init_sr()
- some typoes

* Tue Sep 1 2009 Junjie Wei <junjie.wei@oracle.com> - 2.3-10
- bugfix in list_dir()
- bugfix in cluster_setup() and utils/repos.py
- move upgrade function to agent startup script
- ovs_backup(): umount before backup if necessary

* Mon Aug 31 2009 Junjie Wei <junjie.wei@oracle.com> - 2.3-10
- various bugfix according to pylint report

* Fri Aug 28 2009 Junjie Wei <junjie.wei@oracle.com> - 2.3-10
- bugfix in install_vm_*() and create_dummy_vm()
- add open-ovf requirement to ovs-agent.spec
- enhancement of storage management: delele and init.
- bugfix in prepare_cluster_root()
- parse both /etc/matab and /etc/fstab for storage conversion

* Thu Aug 27 2009 Junjie Wei <junjie.wei@oracle.com> - 2.3-10
- raise exception when mount/umount fails
- bugfix of storage mount
- rewrite prepare_cluster_root() to avoid potential bugs
- bugfix in register_vm()
- sr/sp uuid generation enhancement
- enhancement of agent db/conf management

* Wed Aug 26 2009 Junjie Wei <junjie.wei@oracle.com> - 2.3-9
- upgrade_agent.py: start agent before upgrade and stop agent after upgrade
- remove invalid /OVS link when agent starts
- get cluster_root_sr from local db then shared db in cluster_setup()
- change srv roles after master failover
- vip configuration, deal with 2 interfaces with the same ip
- bugfix #8786030
- bugfix #8878156
- add multiprocessing requirement to ovs-agent.spec
- repos.py: print uuid and spec when operation succeeds
- change OVS_BASE to OVS_MOUNT when checking the given path
- use realpath when init the sr

* Tue Aug 25 2009 Junjie Wei <junjie.wei@oracle.com> - 2.3-9
- utils/repos.py: list/new sr, set root sr
- bugfix #8790371, start o2cb before mount
- bugfix #8810005, add python-simplejson requirement to ovs-agent.spec

* Tue Aug 25 2009 Tiger Zhang <tiger.zhang@oracle.com> - 2.3-9
- bugfix #8832619, move server_mode table to local db.

* Mon Aug 24 2009 Junjie Wei <junjie.wei@oracle.com> - 2.3-9
- enhancement of sr management and ha setup

* Mon Aug 24 2009 Tiger Zhang <tiger.zhang@oracle.com> - 2.3-9
- bugfix #8775481, explicit source image type for qemu-img.
- bugfix #8819828, "vtech" exception.

* Fri Aug 20 2009 Junjie Wei <junjie.wei@oracle.com> - 2.3-9
- rewrite sr management script
- init all sr when agent starts
- bugfix #8805946

* Thu Aug 20 2009 Hongxi Ma <hongxi.ma@oracle.com> - 2.3-9
- bugfix #8817097,8817155

* Wed Aug 19 2009 Junjie Wei <junjie.wei@oracle.com> - 2.3-9
- bugfix of counter initialization in cluster_generate_ocfs2_cluster_conf().
- multi-sr support, rewrite find_real_path(), etc.

* Mon Aug 17 2009 Junjie Wei <junjie.wei@oracle.com> - 2.3-8
- bugfix #8795105
- bugfix in cluster_setup(), always init root sr.
- better error message for server selection
- start cluster heartbeat when ha is enabled

* Mon Aug 17 2009 Tiger Zhang <tiger.zhang@oracle.com> - 2.3-8
- Block unpause/restore in maintenance mode.
- Make add_vm_disk works for phy.

* Wed Aug 12 2009 Junjie Wei <junjie.wei@oracle.com> - 2.3-8
- Storage management: iSCSI support.

* Tue Aug 11 2009 Hongxi Ma <hongxi.ma@oracle.com> - 2.3-7
- bugfix #8776626, all the password sections are masked in log

* Tue Aug 11 2009 Junjie Wei <junjie.wei@oracle.com> - 2.3-7
- start o2cb service when ovs-agent starts
- update utils/config_o2cb.sh
- update utils/upgrade_agent.py
- update ovs-agent post installation script

* Tue Aug 11 2009 Tiger Zhang <tiger.zhang@oracle.com> - 2.3-7
- bugfix #8780513
- Create the CDS lock file if absent.

* Mon Aug 10 2009 Junjie Wei <junjie.wei@oracle.com> - 2.3-7
- bugfix #8774588

* Mon Aug 10 2009 Hongxi Ma <hongxi.ma@oracle.com> - 2.3-7
- bugfix #8773952

* Mon Aug 10 2009 Tiger Zhang <tiger.zhang@oracle.com> - 2.3-7
- Support attach/deattach phy disk.
- Simplify the exposed wrapper.
- Make xmlrpcdoc works. Add a section Module section in doc.
- BUG 8774563. Make sure the script is runnable.
- Rename ova_extract.
- More detailed OVF method docs.

* Fri Aug 7 2009 Junjie Wei <junjie.wei@oracle.com> - 2.3-7
- remove hostname restriction of ocfs2 configuration
- update utils/config_o2cb.sh for ocfs2 compatibility
- bugfix #8770454, #8746618

* Fri Aug 7 2009 Hongxi Ma <hongxi.ma@oracle.com> - 2.3-7
- bugfix #8773703

* Thu Aug 6 2009 Junjie Wei <junjie.wei@oracle.com> - 2.3-7
- makerepo2.py: start o2cb service before creating sp and sr
- cluster_init_root_sr(): exclude the master node when doing servers_do

* Thu Aug 6 2009 Hongxi Ma <hongxi.ma@oracle.com> - 2.3-7
- update makerepo2.py to support new type: Partition

* Wed Aug 5 2009 Junjie Wei <junjie.wei@oracle.com> - 2.3-7
- ovs-agent upgrade support: from 2.2 to 2.3
- bugfix #8746601, #8744837, #8721825, #8721722

* Wed Aug 5 2009 Hongxi Ma <hongxi.ma@oracle.com> - 2.3-7
- bugfix #8751657

* Mon Aug 3 2009 Junjie Wei <junjie.wei@oracle.com> -2.3-6
- Bugfix in O2CB configuration

* Mon Aug 3 2009 Tiger Zhang <tiger.zhang@oracle.com> - 2.3-6
- V2V update: correct image path for external v2v, delete vm.cfg, skip copying the same file.

* Mon Aug 3 2009 Hongxi Ma <hongxi.ma@oracle.com> - 2.3-6
- add script: utils/makerepo2.py to facilitate storage setup

* Fri Jul 31 2009 Tiger Zhang <tiger.zhang@oracle.com> - 2.3-6
- Updated Maintenace Mode.
- Added VHD V2V convertion.
- Support deleting source images after V2V.

*Tue Jul 28 2009 Junjie Wei <junjie.wei@oracle.com> -2.3-6
- Non-HA mode support
- Bugfix in /utils/do_heartbeat_nfs.sh
- Bugfix in ocfs2 config sync

* Mon Jul 27 2009 Junjie Wei <junjie.wei@oracle.com> -2.3-5
- New api added: cluster_get_master()

* Fri Jul 24 2009 Hongxi Ma <hongxi.ma@oracle.com> - 2.3-4
- Add api: discover_share_disks

* Fri Jul 24 2009 Tiger Zhang <tiger.zhang@oracle.com> - 2.3-4
- Updated OVF, Reset VM State, Maintenance Mode codes.

*Wed Jul 22 2009 Junjie Wei <junjie.wei@oracle.com> -2.3-4
- bugfix #8712551

*Mon Jul 20 2009 Junjie Wei <junjie.wei@oracle.com> -2.3-3
- bugfix in register_vm(): maximum recursion depth exceeded.

*Tue Jul 16 2009 Junjie Wei <junjie.wei@oracle.com> -2.3-3
- bugfix #8686373
- changes of HA setup and master failover

*Tue Jul 14 2009 Junjie Wei <junjie.wei@oracle.com> - 2.3-2
- rewrite functions about dlm lock and server registration
- update ovs-agent.spec

*Tue Jul 13 2009 Hongxi Ma <hongxi.ma@oracle.com> - 2.3-2
- [bugz 8286], Need an API to get the size of a disk file or a physical device

*Tue Jul 7 2009 Junjie Wei <junjie.wei@oracle.com> - 2.3-1
- Code merge
- HA setup
- Master failover

*Tue Jul 7 2009 Tiger Zhang <tiger.zhang@oracle.com> - 2.3-1
- Draft version of OVF, Reset VM State, Server Maintenance Mode

*Wed Jun 10 2009 Junjie Wei <junjie.wei@oracle.com> - 2.2-86
- bugfix in ha_generate_ocfs2_cluster_conf().

*Wed Jun 10 2009 Tiger Zhang <tiger.zhang@oracle.com> - 2.2-86
- Add a logger ovs.debug. Change logger to local.

*Fri Jun 5 2009 Junjie Wei <junjie.wei@oracle.com> - 2.2-85
- OCFS2 cluster configuration generation enhancement.

*Thu Jun 4 2009 Junjie Wei <junjie.wei@oracle.com> - 2.2-84
- add a new agent configuration option for error messages.
- fmt_err_msg() enhancement.

*Wed Jun 3 2009 Zhigang Wang <zhigang.x.wang@oracle.com> - 2.2-83
- update ovs-agent.spec

* Tue Jun 2 2009 Junjie Wei <junjie.wei@oracle.com> - 2.2-82
- [bugz 8542], rewrite external xend lock mechanism.
- rewrite shared storage check.

* Sun May 31 2009 Hongxi Ma <hongxi.ma@oracle.com> - 2.2-81
- [bugz 9194], "timer_mode" parameter is not set properly by Agent/manager for 64 bit guest in rc2

* Fri May 22 2009 Tiger Zhang <tiger.zhang@oracle.com> - 2.2-80
- [bugz 8472], add logs in agtctl.

*Wed May 13 2009 Hongxi Ma <hongxi.ma@oracle.com>, Tiger Zhang <tiger.zhang@oracle.com>, Junjie Wei <junjie.wei@oracle.com> - 2.2-79
- rewrite run_cmd() to fix the cmd injection vulnerability.
- add unittest for some of the APIs.

*Tue May 12 2009 Junjie Wei <junjie.wei@oracle.com> -2.2-79
- [bugz 8970], get memory infomation from `xm info`

*Fri May 8 2009 Junjie Wei <junjie.wei@oracle.com> - 2.2-79
- rewrite get_agent_version(), returns version of the running agent

*Fri Apr 30 2009 Junjie Wei <junjie.wei@oracle.com> -2.2-78
- [bugz 8797], sync dlm locks when ha is enabled/disabled or agent starts; introduces dlm db.
- [bugz 8831], typo in get_host_info().
- [bugz 8725], remove .listing file when processing ftp directory download.
- [bugz 8860], do not allow to package/cp vm with device-based disks. allow tap:aio type device-based disks.
- set wget time out to 10 seconds and tries to 2.
- typo in ha_set_shutdown_mode()
- [bugz 8762], introduce threading to avoid monitor process blockage.

*Mon Apr 20 2009 Junjie Wei <junjie.wei@oracle.com> - 2.2-77
- get_storage_repositories() enhancement: cluster shared storage root entry probe.

*Thu Apr 16 2009 Junjie Wei <junjie.wei@oracle.com> - 2.2-76
-[bugz 8649, 8597], sync cluster shared storage settings to new servers in the cluster when cluster HA is enabled.

*Thu Apr 9 2009 Junjie Wei <junjie.wei@oracle.com> - 2.2-75
- [bugz 8657], use synchronous run_cmd instead of asyncronous rum_cmd_bg to avoid database update lost.

*Tue Mar 31 2009 Dyno Fu <dyno.fu@oracle.com> - 2.2-74
- WLOC perf metrics collection. affected api list below,
  get_vm_perf_metrics()
  get_server_perf_metrics()
  get_server_xm_info()
  get_storage_repositories()
  get_live_vm_info()

*Mon Mar 30 2009 Dyno Fu <dyno.fu@oracle.com> - 2.2-73
- [bugz 8460], pad number with leading zero when generate mac

*Mon Mar 16 2009 Dyno Fu <dyno.fu@oracle.com> - 2.2-72
- [bugz 6757], add ha_remove_cluster_infrastructure()

*Wed Mar 11 2009 Dyno Fu <dyno.fu@oracle.com> - 2.2-71
- [bugz 7048,7457],[bug 8229141], add ovs-agent to /var/lock/subsys/ to 
  stop agent properly when user manually shutdown the server.

*Mon Mar 9 2009 Tiger Zhang <tiger.zhang@oracle.com> - 2-2.70
- [bugz 8116], V2V importing failed. Fixed. Duplicate [bugz 7583].

*Sat Mar 7 2009 Dyno Fu <dyno.fu@oracle.com> - 2-2.70
- [bugz 8269], generated cluster.conf has duplicated hostname.

*Thu Mar 5 2009 Junjie Wei <junjie.wei@oracle.com> - 2.2-70
- [bugz 8263], use --no-p option to keep destination permissions

*Tue Mar 3 2009 Junjie Wei <junjie.wei@oracle.com> - 2.2-70
- new api to get all registered servers in the server pool: get_registered_servers()

* Tue Feb 27 2009 Dyno Fu <dyno.fu@oracle.com> - 2.2-70
- modify db_get_real_vm_path() to solve nfs not sync problem [bugz 8108,6759].

* Thu Feb 26 2009 Junjie Wei <junjie.wei@oracle.com> -2.2-70
- bugfix of check_sys_passwd(), change destination file name.

* Fri Feb 20 2009 Junjie Wei <junjie.wei@oracle.com> - 2.2-69
- [bugz 8103], return the server on which the operation is done for
  install_vm_hvm/para(), start_vm()
- [bugz 8143], when attaching a shared disk to a vm, use force attach option "!".
- [bugz 8144], use mode option "!" instead of string "shareddisk" for shared disk check

* Tue Feb 17 2009 Dyno Fu <dyno.fu@oracle.com> - 2.2-69
- [bugz 8108], use the hostserver where the vm is currently running to get the realpath
  to workaround the nfs sync problem as in [bugz 6759].
  get_vm_vnc_conn(), get_vm_config()

* Thu Feb 12 2009 Dyno Fu <dyno.fu@oracle.com> - 2.2-68
- [bugz 8056], adjust remove sequence, put the error prone detatch first.

* Mon Feb 09 2009 Dyno Fu <dyno.fu@oracle.com> - 2.2-67
- [bugz 7657,7835], for a paused vm, xm shutdown won't work. unpause it before doing that.

* Wed Feb 04 2009 Dyno Fu <dyno.fu@oracle.com> - 2.2-66
- [bugz 7991], xen_get_vms_name_vncport_macs() exception when vncport cannot be retrieved
  from xenstore.

* Mon Jan 12 2009 Dyno Fu <dyno.fu@oracle.com> - 2.2-65
- [bugz 7822], get_live_vms() should restore timout setting.

* Mon Jan 12 2009 Dyno Fu <dyno.fu@oracle.com> - 2.2-65
- [bugz 7296], register server reuse what already in db, rather than raise Exception.

* Wed Dec 24 2008 Dyno Fu <dyno.fu@oracle.com> - 2.2-64
- [bugz 7646], import running vm, use the original uuid.

* Wed Dec 24 2008 Dyno Fu <dyno.fu@oracle.com> - 2.2-63
- enhance utl_extract_vm() to deal with vm tarball inside directory.

* Mon Dec 22 2008 Dyno Fu <dyno.fu@oracle.com> - 2.2-63
- [bugz 7728, 7729] implement utl_nfs_cp()
- [bugz 7646], after create a vm from scratch, create a uuid if not available already.

* Wed Dec 17 2008 Junjie Wei <junjie.wei@oracle.com> - 2.2-62
- [bugz 7602, 7661] add a new api config_vm(), to configure the guest vm
- [bugz 7606] add a new api copy_props_into_vm(), to generate a property file and copy it into the vm

* Tue Dec 16 2008 Dyno Fu <dyno.fu@oracle.com> - 2.2-62
- [bugz 7674], implement get_vm_policy()/get_vm_attr()

* Fri Dec 12 2008 Junjie Wei <junjie.wei@oracle.com> - 2.2-61
- add OVSImageOperation.py, copyFileIntoVM()

* Wed Dec 10 2008 Tiger Zhang <tiger.zhang@oracle.com> - 2.2-61
- [bugz 7484], add a new API named xen_get_cdrom_frontend for getting front end name of cdrom device.

* Tue Dec 09 2008 Dyno Fu <dyno.fu@oracle.com> - 2.2-61
- replace uuid gen with get_uuid()
- [bugo 7626690][bugz 7649], only sync ocfs2 cluster configure to the newly
  registered server when ha is enabled.
- [bugz 7603], nfs_export_iso() utl_nfs_export_iso()

* Mon Dec 01 2008 Dyno Fu <dyno.fu@oracle.com> - 2.2-61
- implement get_vm_perf_metrics() and get_server_perf_metrics()

* Wed Nov 26 2008 Dyno Fu <dyno.fu@oracle.com> - 2.2-61
- cleanup source code file name.

* Wed Nov 26 2008 Junjie Wei <junjie.wei@oracle.com> - 2.2-61
- add get_server_config() and get_network_config()
- add a new file OVSXAPIUtil.py

* Mon Nov 24 2008 Dyno Fu <dyno.fu@oracle.com> - 2.2-61
- move dispatch service to OVSServices
- integrate XenAPI to ovs-agent

* Thu Nov 20 2008 Dyno Fu <dyno.fu@oracle.com> - 2.2-60
- [bugz 7564], no return value for get_free_space_vm() when error occures.

* Thu Nov 13 2008 Dyno Fu <dyno.fu@oracle.com> - 2.2-60
- [bugz 7688], add ha_check_storage_cluster_root() for validation

* Tue Nov 04 2008 Dyno Fu <dyno.fu@oracle.com> - 2.2-59
- [bugz 7076], set rpc timeout to 15 in get_live_vms()

* Tue Nov 04 2008 Dyno Fu <dyno.fu@oracle.com> - 2.2-59
- [bugz 7338], after cp vm, duplate a db record and update 'manual_shutdown'
  to True. so that the newly created vm won't startup when HA enabled for it.

* Mon Nov 03 2008 Dyno Fu <dyno.fu@oracle.com> - 2.2-59
- [bugz 7344], remove oflag=direct, when specified will cause "Invalid argument".

* Fri Oct 31 2008 Hongxi Ma <hongxi.ma@oracle.com> 2.2-58
- [bugz 7365], After do the cancel operation, system.img is not deleted

* Tue Oct 28 2008 Dyno Fu <dyno.fu@oracle.com> 2.2-58
- [bugz 7362], dd on ext3 file system does not support "oflag=direct".

* Tue Oct 28 2008 Junjie Wei <junjie.wei@oracle.com> 2.2-58
- [bugz 7327], enhancement of get_host_info(), getting info before server registration supported

* Mon Oct 27 2008 Dyno Fu<dyno.fu@oracle.com> - 2.2-57
- [bugz 7332], using open-ovf tool to generate vm.cfg, env file, etc

* Fri Oct 24 2008 Dyno Fu<dyno.fu@oracle.com> - 2.2-57
- [bugz 7344], utl_cp_vm() now uses dd instead of copytree() for efficiency
- [bugz 7285], unregister server will remove the dlm lock line from xend-config.sxp

* Fri Oct 24 2008 Junjie Wei <junjie.wei@oracle.com> - 2.2-57
- [bugz 7297], implement update_sys_passwd() and check_sys_passwd()

* Thu Oct 23 2008 Hongxi Ma <hongxi.ma@oracle.com> - 2.2-57
- add new api: get_vm_config which return all the configs in vm.cfg in the format of XML

* Thu Oct 23 2008 Dyno Fu <dyno.fu@oracle.com> - 2.2-57
- [bugz 7296], implement update_agent_password()
- [bugz 7332], implement get/set_vm_ovf_env_file()
- when register_vm set manual_shutdown = True [bugz 7338]
  when detect vm is RUNNING set manual_shutdown = False [bugz 7276][bugz 7236]
  start the vm <=> vm is DOWN and manual_shutdown == False

* Wed Oct 22 2008 Hongxi Ma <hongxi.ma@oracle.com> - 2.2-57
- [bugz 7316], to add xen_correct_cfg in utl_cp_vm

* Tue Oct 21 2008 Dyno Fu <dyno.fu@oracle.com> - 2.2-57
- [bugz 7312], num_in_the_cluster -> num_in_cluster

* Mon Oct 20 2008 Junjie Wei <junjie.wei@oracle.com> - 2.2-56
- [bugz 6670], correct vm config file after creating a dummy vm for pvm pxe boot

* Wed Oct 15 2008 Dyno Fu <dyno.fu@oracle.com> - 2.2-56
- [bugz 7276], ha feature does not work for manually started vm.

* Tue Oct 14 2008 Tiger Zhang <tiger.zhang@oracle.com> - 2.2-56
- [bugz 7141], add setting add os type and variant.
- Fixed bug in vmx parser in case when account of sections is more than 2. (e.g. vmware.tools.version = "7702")

* Thu Oct 08 2008 Hongxi Ma <hongxi.ma@oracle.com> - 2.2-55
- api list_dir is enhanced to support an exta param: level which takes a default vaule 1

* Tue Oct 07 2008 Dyno Fu <dyno.fu@oracle.com> - 2.2-54
- [bugz 7236], for an already running vm, import it and enable ha does not take effect.

* Mon Oct 06 2008 Dyno Fu <dyno.fu@oracle.com> - 2.2-54
- delete member nodes first when unregister master node.

* Wed Sep 24 2008 Dyno Fu <dyno.fu@oracle.com> - 2.2-53
- [bugz 4103], filter server without hvm capability when install hvm vm from scratch.

* Tue Sep 23 2008 Dyno Fu <dyno.fu@oracle.com> - 2.2-52
- [bugz 5835], set_vm_config_param(), for pass extra parameter to vm.cfg

* Tue Sep 16 2008 Dyno Fu <dyno.fu@oracle.com> - 2.2-52
- [bugz 7076], change server's status in OVSMonitorServer.check_server_status()

* Wed Sep 03 2008 Dyno Fu <dyno.fu@oracle.com> - 2.2-52
- [bugz 7048], disable nowayout when shutdown the server from agent.

* Mon Sep 01 2008 Dyno Fu <dyno.fu@oracle.com> - 2.2-52
- [bug 7357167], deal with memory over allocate problem
- [bugz 7032], make the master node have the minest node num in ocfs2 cluster conf

* Fri Aug 29 2008 Dyno Fu <dyno.fu@oracle.com> - 2.2-52
- [bugz 7027], when the master agent goes live, call ha_setup_cluster_infrastructure()

* Thu Aug 28 2008 Tiger Zhang <tiger.zhang@oracle.com> - 2.2-51
- [bugz 7015], correct a typo.

* Wed Aug 27 2008 Dyno Fu <dyno.fu@oracle.com> - 2.2-51
- [bugz 6759], cannot find real vm path due to nfs sync problem.
- get_host_by_name() to get the non-local ip

* Tue Aug 26 2008 Tiger Zhang <tiger.zhang@oracle.com> - 2.2-51
- [bugz 6503], remove vm.cfg when error occurred in v2v converting.

* Tue Aug 26 2008 Dyno Fu <dyno.fu@oracle.com> - 2.2-51
- remove --ignore-length parameter, will have fix in the p2v server side.
- [bugz 6891], deal with existing hdc device in xen_correct_cfg(), which in qemu is reverved for cdrom.
- also affect xen_change_vm_cdrom(), xen_get_avail_disk_slot()

* Mon Aug 25 2008 Dyno Fu <dyno.fu@oracle.com> - 2.2-51
- [bugz 6399], xen_set_vifs() will retain the extra attributes it does not understand.

* Mon Aug 25 2008 Dyno Fu <dyno.fu@oracle.com> - 2.2-50
- update rcp.py for "rsync error:"

* Mon Aug 25 2008 Tiger Zhang <tiger.zhang@oracle.com> - 2.2-50
- add wget parameter --ignore-length for the file in p2v is a link
- set xm shutdown timeout before destroy from 10 mins to 5 mins

* Wed Aug 20 2008 Dyno Fu <dyno.fu@oracle.com> - 2.2-49
- [bugz 6962], use uuid as lock string. name will be vary during vm life cycle.
- [bugz 6853], on_error should NEXT rather than raise Exception.

* Tue Aug 19 2008 Dyno Fu <dyno.fu@oracle.com> - 2.2-49
- [bugz 6759], sync_file_attr() after create the vm disk
- [bugz 6953], add comment to explain ip access control is in CIDR format.
- remove duplicated functions xen_create/delete_disk() in OVSXXenVM which is also in OVSXUtility

* Thu Aug 14 2008 Hongxi Ma <hongxi.ma@oracle.com> - 2.2-48
- [bugz 6936], only if the path is under 'dev' then ignore the check

* Thu Aug 14 2008 Dyno Fu <dyno.fu@oracle.com> - 2.2-48
- [bugz 6913], remove the remote host from known_hosts to avoid host key verification error.
- [bugz 6865], filter virbr## in xen_get_network_bridges()

* Tue Aug 12 2008 Hongxi Ma <hongxi.ma@oracle.com> - 2.2-48
- add tries=2 to limit max test_url awaiting time to 60s

* Tue Aug 12 2008 Dyno Fu <dyno.fu@oracle.com> - 2.2-48
- [bugz 6915], add cancel option in shutdown mode

* Fri Aug 8 2008 Hongxi Ma <hongxi.ma@oracle.com> - 2.2-48
- [bugz 6758], to bypass wget bug(not use '--directory-prefix' sometimes)

* Thu Aug 7 2008 Tiger Zhang <tiger.zhang@oracle.com>
- [bugz 6891], skip hdc to reserve it for cdrom as a workaround.
- [bugz 6802], fixed.

* Wed Aug 6 2008 Dyno Fu <dyno.fu@oracle.com> - 2.2-48
- [bugz 6737], close_fds option for run_cmd_bg()
- revise agtctl stop process for ha
- [bugz 6888], service o2cb configure take the $cluster_name as default

* Tue Aug 5 2008 Dyno Fu <dyno.fu@oracle.com> - 2.2-47
- [bugz 6853], when no server selected to run a vm, donnot mark the vm as ERROR.
- [bugz 6877], revise implement of xen_get_vms_name_vncport_macs()

* Fri Aug 1 2008 Hongxi Ma <hongxi.ma@oracle.com> - 2.2-46
- use cached password to authanticate the API call
- config_agent.py will notify agent to reload cache, so that new password take effect
  immediately.
- "plz" --> "please"

* Fri Aug 1 2008 Dyno Fu <dyno.fu@oracle.com> - 2.2-46
- modify OVSCompat.py to change the the child process's python path

* Thu Jul 31 2008 Hongxi Ma <hongxi.ma@oracle.com> - 2.2-45
- [bugz 6758] Import iso failed due to wget timeout

* Thu Jul 31 2008 Dyno Fu<dyno.fu@oracle.com> - 2.2-45
- [bugz 6737], implement the nowayout lock in OVSAgentGuard.py,
  add --disable-nowayout option to agtctl.
- [bugz 6717], add node to living cluster.

* Mon Jul 28 2008 Dyno Fu<dyno.fu@oracle.com>,Hongxi Ma<hongxi.ma@oracle.com> - 2.2-45
- [bugz 6807], generate empty cluster.conf instead of complain no servers.
- [bugz 6808], consider multiple device with same uuid
- [bugz 6758], Import iso failed due to wget timeout
- [bugz 6817], HA enable, set save/restore vm as manual operation

* Sun Jul 27 2008 Hongxi Ma <hongxi.ma@oracle.com> - 2.2-45
- [bugz 6778] VIF Qos setting can not be deleted in vm.cfg

* Wed Jul 23 2008 Dyno Fu<dyno.fu@oracle.com> - 2.2-44
- [bugz 6737], using service ovsrepositories start. (restart will umount /OVS,
  then the nodes need to rejoin the DLM domain)
- [bugz 6717], local formated ocfs2 should not pass HA prerequisite check.

* Mon Jul 21 2008 Dyno Fu<dyno.fu@oracle.com> - 2.2-43
- [bugz 6707], prevent double mount on /OVS
- [bugz 6731], unregister master, when unregister server from pool

* Thu Jul 17 2008 Dyno Fu<dyno.fu@oracle.com> - 2.2-42
- replace tunefs.ocfs2 with debugfs.ocfs2 for segment fault bug.
- using debugfs to detect server failure.

* Wed Jul 16 2008 Tiger Zhang<tiger.zhang@oracle.com>
- implement v2v_cancel.
- add https support.

* Wed Jul 09 2008 Tiger Zhang<tiger.zhang@oracle.com>
- implement asynchronous v2v.
- add preference paramater to get_utility_server
- use share CDS in db_get_srv
- add share lock in OVSFileLock.py
- add procname utility
- add LOCK_SH support in OVSCDS.py

* Wed Jul 09 2008 Dyno Fu<dyno.fu@oracle.com> - 2.2-41
- restrict one server can only be registered to one pool
- treat "file:"/"tap:aio:" equal in xen_correct_cfg()

* Tue Jul 08 2008 Hongxi Ma <hongxi.ma@oracle.com> - 2.2-40
- allow user to specify disk position in add_vm_disk, returns front end name
- remove_vm_disk returns the orignal disk position
- new function check_hvm_pvdriver
- re-wrote test_url to remove potential bugs
- status inquery/cancel ability for create_vm_disk

* Mon Jul 07 2008 Dyno Fu <dyno.fu@oracle.com> - 2.2-40
- add dlm.py for xend external lock interface

* Sat Jul 05 2008 Dyno Fu <dyno.fu@oracle.com> - 2.2-39
- OVSCompat.py to use the compatible version of libvirt and python-virtinst

* Tue Jul 01 2008 Dyno Fu <dyno.fu@oracle.com> - 2.2-38
- ha_check_cluster_prerequisite()
- xen.xend.uuid need random.seed to initialize generator
- ha_generate_ocfs2_cluster_conf()

* Tue Jul 01 2008 Hongxi Ma<hongxi.ma@oracle.com> - 2.2-37
- Improved status inquery for ftp resource downloading
- support specifying 'keymap' while install new VM

* Sat Jun 28 2008 Dyno Fu<dyno.fu@oracle.com> - 2.2-36
- implement check cluster status
- implement dlm lock creation
- handle uuid, 1) if not exists add it 2)after cp update it

* Wed Jun 25 2008 Hongxi Ma<hongxi.ma@oracle.com> - 2.2-35
- new QoS agent interface to harmonise the new QoS implemtation in xend

* Wed Jun 25 2008 Dyno Fu<dyno.fu@oracle.com> - 2.2-35
- add OVSSiteHA.py, OVSXHA.py, OVSMonitorServer.py (not fully implemented yet)
- modify do_rpc.py, default to call local agent

* Wed Jun 25 2008 Tiger Zhang<tiger.zhang@oracle.com> - 2.2-34
- add sparse format(KDMV) support in vmdk parser
- fix du path containing spaces issue
- fix get_vmdk_list bug
- enhance converting process
- add checking free space and deleting downloaded files

* Wed Jun 18 2008 Dyno Fu<dyno.fu@oracle.com> - 2.2-34
- allow user to manual_shutdown when autostart is enabled

* Tue Jun 17 2008 Tiger Zhang<tiger.zhang@oracle.com> - 2.2-33
- Implement V2V without using vmware-vdiskmanager

* Tue Jun 17 2008 Hongxi Ma<hongxi.ma@oracle.com> - 2.2-33
- improved status inquery for resource importing
- async cancel ability improved

* Tue Jun 17 2008 Dyno Fu <dyno.fu@oracle.com> - 2.2-33
- when master nodes ready, sync the mount point on member nodes
- make the monitor->trigger->action based autorestart work

* Fri Jun 13 2008 Dyno Fu <dyno.fu@oracle.com> - 2.2-33
- [bugz 6425], xenstore-ls -> xenstore-read

* Tue Jun 10 2008 Hongxi Ma<hongxi.ma@oracle.com> - 2.2-32
- [bugz 6372], VD Priority Configuration in vm.cfg was not removed after delete a VD
- [bugz 6363], There are 2 QoS configures after change hard driver type
- get_vm_uptime, new interface to query the uptime of a vm
- utl_wget_status,improve the status query: success:filename:downloaded size:progress

* Tue Jun 10 2008 Tiger Zhang<tiger.zhan@oracle.com> - 2.2-32
- [bugz 6410], Can't not import a virtual machine image which locals in uuid repositories
- V2V, Add checking vmware-vdiskmanager before v2v convertion
- [bugz 6384], fixed cannot add more than 2 ide disk

* Tue Jun 10 2008 Dyno Fu <dyno.fu@oracle.com> - 2.2-32
- add OVSXSysInfo.py, implement get_oracle_vm_release(), get_agent_version()

* Fri Jun 6 2008 Tiger Zhang<tiger.zhang@oracle.com> - 2.2-32
- [bugz 6410], v2v source path with UUID

* Fri Jun 6 2008 Dyno Fu<dyno.fu@oracle.com> - 2.2-32
- [bugz 6384], fixed cannot add more than 2 ide disk

* Mon Jun 02 2008 Tiger Zhang<tiger.zhang@oracle.com>, Dyno Fu<dyno.fu@oracle.com>
  Hongxi Ma <hongxi.ma@oracle.com>  - 2.2-31
- V2V   Verify source directory
- [bugz 6180], vmware image import does not work on 2.1.2
- QoS   bugs fixing, new interfaces, tests
- test_url timeout enabled

* Tue May 27 2008 Tiger Zhang<tiger.zhang@oracle.com>, Dyno Fu<dyno.fu@oracle.com>
  Hongxi Ma <hongxi.ma@oracle.com>  - 2.2-30
- Add V2V feature
  V2V: Convert VMware vm to Oracle VM, integration with manager done
- Added api select_migration_target() to show the migration target at manager
  side
- QoS code (VIF part) done

* Tue May 20 2008 Hongxi Ma <hongxi.ma@oracle.com> - 2.2-29
- merged the cpu-pin and keymap

* Tue May 20 2008 Dyno Fu<dyno.fu@oracle.com> - 2.2-28
- implement remaster process for HA

* Wed Apr 30 2008 Dyno Fu<dyno.fu@oracle.com>
- using pid to track agent processes status

* Tue Mar 11 2008 Junjie Wei<junjie.wei@oracle.com>, Dyno Fu<dyno.fu@oracle.com>
- [bugz 5406], pxe boot failed after set vif

* Fri Mar 07 2008 Junjie Wei<junjie.wei@oracle.com>
- [bugz 5379], set timeout for testing connection
- [bugz 5380], deal with vif=['']
- [bugz 5381], will not automatically change the type of vif but return fail
- [bugz 5384], remove mac info from default vm.cfg for pvm PXE booting

* Tue Feb 28 2008 Dyno Fu<dyno.fu@oracle.com>
- [bugz 5318], implement get_free_memory()
- [bugz 5305], implement get_vm_avail_disk_slot()

* Tue Feb 26 2008 Hongxi Ma<hongxi.ma@oracle.com>
- [bugz 5305], rewrote next_fe_de

* Tue Feb 26 2008 Dyno Fu<dyno.fu@oracle.com>
- [bugz 5294], select_tgt_host() should use real_vm_path to check vm type

* Mon Feb 18 2008 Dyno Fu<dyno.fu@oracle.com>
- add version check for site agent operations for backward compatibility

* Wed Jan 31 2008 Dyno Fu<dyno.fu@oracle.com>
- [bugz 4731], add xen_/optimize_os_profile()

* Wed Jan 30 2008 Dyno Fu<dyno.fu@oracle.com>
- [bugz 4731], os profile support for hvm installation
- add xen_remove_shared_disk() when cp_vm() in the same site

* Wed Jan 30 2008 Hongxi Ma<hongxi.ma@oracle.com>
- [bugz 5120], new xen_get_network_bridges

* Tue Jan 29 2008 Junjie Wei<junjie.wei@oracle.com>
- [bugz 5039], utl_wget() download file/dir to temp dir .wget

* Thu Jan 25 2008 Dyno Fu<dyno.fu@oracle.com>
- set_vm_vifs()/xen_set_vifs() remove is_append add mode parameter
- get_servers_vcaps() to support datacollector to detect server hvm support

* Thu Jan 24 2008 Dyno Fu<dyno.fu@oracle.com>
- filter server without hardware caps to run the vm. add xen_hypervisor_info()

* Thu Jan 22 2008 Dyno Fu<dyno.fu@oracle.com>
- [bugz 5058], add remove cdrom functionality to change_vm_cdrom()

* Tue Jan 22 2008 Hongxi Ma<hongxi.ma@oracle.com>
- [bugz 3990], monitor wget status periodically in asynchronous mode.

* Mon Jan 21 2008 Hongxi Ma<hongxi.ma@oracle.com>
- add asynchronous task scheduler

* Thu Jan 17 2008 Dyno Fu<dyno.fu@oracle.com>
- [bugz 4561], add device type support for set/get vif configuration
- [bugz 4996], remove dump file vm.save after restore

* Thu Jan 17 2008 Hongxi Ma<hongxi.ma@oracle.com>
- [bugz 4712], set_vm_preferred_servers/get_vm_preferred_servers to support
  setting preferred servers for a VM

* Thu Jan 10 2008 Junjie Wei<junjie.wei@oracle.com>
- Keep cdrom during installation to support windows installation
- restore_vm(), install_vm_*() enhancement, dedicated servers supported
- rename suspend_vm()/resume_vm() to pause_vm()/unpause_vm(), in line with xm
- get_agent_version() implemented
- config_boot_sequence() implemented, boot from hard disk, cdrom or network
- get_host_info() enhancement, xen_caps info included
- rename get_hw_caps() to get_xen_caps()
- add a file lock for vm.cfg to avoid write contention
- fixed [bugz 3994, 4888, 4679, 4242, 4706]

* Thu Jan 10 2008 Dyno Fu<dyno.fu@oracle.com>
- support up to 4 disks for hvm
- [bugz 4010], password modification will not take effect immediately
- [bugz 4707], modify vm configuration at runtime

* Tue Nov 13 2007 Dyno Fu<dyno.fu@oracle.com>
- [bugz 4536], donnot remove original type setting, only workaround
  not a full solution

* Sat Nov 10 2007 Dyno Fu<dyno.fu@oracle.com>, Junjie Wei<junjie.wei@oracle.com>
- Hid ssl configuration, [bugz 4479]
- Applied find_real_path() to cdrom/iso when install vm, [bugz 4483]
- Implemented get_target_path() for cross-site cp storage balance,
- Change remove() behavior, [bugz 4484]

* Fri Nov 09 2007 Kevin Lyons <kevin.x.lyons@oracle.com>
- Set ssl to enabled by default in agent.ini.default
- Added post install script to generate keys

* Sat Nov 03 2007 Dyno Fu<dyno.fu@oracle.com>
- impelent get_vm_vifs() & xen_get_vifs()

* Thu Nov 01 2007 Dyno Fu<dyno.fu@oracle.com>
- replace rpc.exp with rcp.py in favor of pexpect

* Thu Nov 01 2007 Dyno Fu<dyno.fu@oracle.com>
- replace parameter vif->vif_cfg in function install_vm*()

* Wed Oct 31 2007 Dyno Fu<dyno.fu@oracle.com>
- implement get_network_bridges(), set_vm_vifs(), clear_vm_vif_mac()

* Sat Oct 27 2007 Dyno Fu<dyno.fu@oracle.com>
- before migrate vm, check if the 2 server share same storage view.

* Sat Oct 27 2007 Junjie Wei<junjie.wei@oracle.com>
- set vm install, add params vnclisten, vncpasswd, tablet, keep-cdrom
  (patch virt-install required)

* Thu Oct 25 2007 Dyno Fu<dyno.fu@oracle.com>
- fix [bugz 3392], handle multiple partition

* Thu Oct 25 2007 Junjie Wei<junjie.wei@oracle.com>
- [bugz 4063],4013,4106,4107,4064
- implement check_shared_storage(), get_hw_caps(), get_host_arch() and is_bootable()

* Tue Oct 23 2007 Dyno Fu<dyno.fu@oracle.com>
- [bugz 3994,4008,4011,4022]

* Tue Oct 16 2007 Junjie Wei<junjie.wei@oracle.com>
- various bugfix
- implement get_host_info

* Wed Oct 10 2007 Junjie Wei<junjie.wei@oracle.com>
- fix [bugz 3750], do not log the vnc password
- remove uuid when install vm from scratch

* Sun Oct 9 2007 Dyno Fu<dyno.fu@oracle.com>
- modify utils/config_agent.py to fix various bugs.

* Sun Oct 1 2007 Dyno Fu<dyno.fu@oracle.com>
- rename ovsagent to ovs-agent

* Sun Sep 30 2007 Dyno Fu<dyno.fu@oracle.com>, Junjie Wei<junjie.wei@oracle.com>
- rewrite change cdrom function
- various bugfix

* Sat Sep 29 2007 Junjie Wei<junjie.wei@oracle.com>
- implement add_vm_vif, del_vm_vif, get_vm_vnc_password, set_vm_vnc_password

* Sat Sep 29 2007 Dyno Fu<dyno.fu@oracle.com>
- rewrite get_vms_perf, loop throu servers not vms
- patch db_recovery, consider more cases

* Tue Sep 25 2007 Dyno Fu<dyno.fu@oracle.com>, Junjie Wei<junjie.wei@oracle.com>
- complete all the functions implemented previous
- rewrite agtctl, add client timeout to tackle cannot quit
  when child process running problem.

* Wed Sep 19 2007 Dyno Fu<dyno.fu@oracle.com>
- implement ssl support, but disable by default
- reorganize code layout

* Wed Sep 5 2007 Junjie Wei<junjie.wei@oracle.com>, Dyno Fu<dyno.fu@oracle.com>
- implement vm installation from scratch (hvm & para)
- check free disk space before cp vm, create vm disk, vm installation etc
- update exported function inline document

* Tue Aug 21 2007 Dyno Fu <dyno.fu@oracle.com>
- rewrite OVSSiteAgent process logic
- implement get vnc connection string
- fix [bugz 3249], [bugz 3233]

* Tue Jul 24 2007 Dyno Fu <dyno.fu@oracle.com>
- reenable configure network, pass parameter throu kernel cmdline

* Sat Jul 21 2007 Dyno Fu <dyno.fu@oracle.com>
- start vm remove invalid disk path
- add default config file, try not to overwrite previous config
- various bugfix

* Thu Jul 19 2007 Dyno Fu <dyno.fu@oracle.com>
- better exception/error logging "err msg=> %s: %s" % (e.__class__.__name__, e)
- run_cmd handle cmd more consistently
- reorg site db
- add READLOCK status & reference counter 'readlock' to allow concurrent cp
- add license comment
- add security check for any write operation upon vm
- add register default site when agent start
- broadcast (mac, ip) & get mac with xm list --long (in fact alot of other information)
- implement /etc/init.d/ovsagent configure

* Thu May 25 2007 Dyno Fu <dyno.fu@oracle.com>
- modify post configuration

* Thu Jan 11 2007 Zhigang Wang <zhigang.x.wang@oracle.com>
- initial ovsagent spec file
